pub struct BatchPrefetcher<T> { /* private fields */ }Expand description
Background prefetcher that fills a bounded queue with sample batches.
Implementations
Sourceimpl<T: Send + 'static> BatchPrefetcher<T>
impl<T: Send + 'static> BatchPrefetcher<T>
Sourcepub fn next(&self) -> Result<T, SamplerError>
pub fn next(&self) -> Result<T, SamplerError>
Block until the next prefetched batch is available.
Sourcepub fn produced_count(&self) -> usize
pub fn produced_count(&self) -> usize
Total number of batches produced by the background worker.
Sourcepub fn error_count(&self) -> usize
pub fn error_count(&self) -> usize
Total number of errors produced by the background worker.